<?php
/*
 *
 * SCD Hide From Groups Plugin
 * Developed by Dylan Myers (dylanspcs@gmail.com)
 * For Skin City Designs, Free MyBB Plugins Category
 * Copyright Skin City Designs
 *
 */

// Disallow direct access to this file for security reasons
if(!defined("IN_MYBB"))
{
	die("Direct initialization of this file is not allowed.<br /><br />Please make sure IN_MYBB is defined.");
}

$plugins->add_hook("parse_message_start", "scd_hide_fg_parse_message");
$plugins->add_hook("parse_quoted_message", "scd_hide_fg_parse_reply");

function scd_hide_fg_info()
{
	return array(
		"name"					=> "SCD Hide From Groups (Free SCD Plugin)",
		"description"		=> "When activated it will hide the contents of selected MyCode tags in your posts from selected groups.",
		"website"				=> "http://www.skincitydesigns.com",
		"author"				=> "Dylan Myers",
		"authorsite"			=> "http://www.skincitydesigns.com",
		"version"				=> "2.0",
		"guid"					=> "d7c1c362799826b1b772efa874be1d54",
		"compatibility" 		=> "14*,16*",
	);
}

function scd_hide_fg_install()
{
	global $db, $mybb;

	$scd_hide_fg_group = array(
		"gid"					=> "NULL",
		"name"				=> "scd_hide_fg",
		"title"				=> "SCD Hide From Groups",
		"description"	=> "Hide the contents of selected MyCode tags in your posts from selected groups.",
		"disporder"		=> "500",
		"isdefault"			=> "no",
	);
	$db->insert_query("settinggroups", $scd_hide_fg_group);
	$gid = $db->insert_id();
	
	$setting = array(
        "sid"					=> "NULL",
        "name"				=> "scd_hide_fg_groups",
        "title"				=> "Comma separated list of groups you wish to have the code and php boxes hidden from.",
        "description"	=> "Please enter a comma separated list of groups.",
        "optionscode"	=> "text",
        "value"				=> "",
        "disporder"		=> "1",
        "gid"					=> intval($gid),
        );
    $db->insert_query("settings", $setting);
	
	$setting = array(
        "sid"					=> "NULL",
        "name"				=> "scd_hide_fg_forums",
        "title"				=> "Forums To Be Hidden",
        "description"	=> "Enter a comma separated list of forum IDs that you want this to affect. If left blank it will affect all forums.",
        "optionscode"	=> "text",
        "value"				=> "",
        "disporder"		=> "2",
        "gid"					=> intval($gid),
        );
    $db->insert_query("settings", $setting);
	
	$setting = array(
        "sid"					=> "NULL",
        "name"				=> "scd_hide_fg_text",
        "title"				=> "Text to be displayed to the blocked groups.",
        "description"	=> "Please enter the text you wish to be displayed.",
        "optionscode"	=> "textarea",
        "value"				=> "The contents of this section are hidden for your group",
        "disporder"		=> "3",
        "gid"					=> intval($gid),
        );
    $db->insert_query("settings", $setting);
	
	$setting = array(
        "sid"					=> "NULL",
        "name"				=> "scd_hide_fg_tohide",
        "title"				=> "What to Hide",
        "description"	=> "Please enter a comma separated list of MyCodes you wish to hide.",
        "optionscode"	=> "text",
        "value"				=> "PHP,CODE,QUOTE,URL,IMG,EMAIL",
        "disporder"		=> "4",
        "gid"					=> intval($gid),
        );
    $db->insert_query("settings", $setting);
	
	rebuild_settings();
}

function scd_hide_fg_uninstall()
{
	global $db, $mybb;
	
	$db->delete_query("settings","name IN('scd_hide_fg_groups', 'scd_hide_fg_text', 'scd_hide_fg_tohide', 'scd_hide_fg_forums')");
	$db->delete_query("settinggroups", "name = 'scd_hide_fg'");
	
	rebuild_settings();
}

function scd_hide_fg_is_installed()
{
	global $db;
	
	$query = $db->simple_select("settinggroups", "COUNT(*) as rows", "name='scd_hide_fg'");
	$rows = $db->fetch_field($query, "rows");
	if($rows > 0)
	{
		return true;
	}
	
	return false;
}

function scd_hide_fg_activate()
{
}

function scd_hide_fg_deactivate()
{
}

function scd_hide_fg_parse_message($message)
{
	global $db, $mybb, $fid;

	// Parse the message for code tags, and replace the contents with a little message.
	if(in_array($mybb->user['usergroup'], explode(',', $mybb->settings['scd_hide_fg_groups'])))
	{
		if(!empty($mybb->settings['scd_hide_fg_forums']) && !in_array($fid, explode(',', $mybb->settings['scd_hide_fg_forums'])))
		{
			return $message;
		}
		foreach(explode(',', $mybb->settings['scd_hide_fg_tohide']) as $tag)
		{
			if(!preg_match('#quote#i', $tag))
			{
				$message = preg_replace('#\['.$tag.'\].*?\[/'.$tag.'\]#si', '['.$tag.']'.$mybb->settings['scd_hide_fg_text'].'[/'.$tag.']', $message);
				$message = preg_replace('#\['.$tag.'=.*?\].*?\[/'.$tag.'\]#si', '['.$tag.'='.$mybb->settings['scd_hide_fg_text'].']'.$mybb->settings['scd_hide_fg_text'].'[/'.$tag.']', $message);
			}
			else if (preg_match('#quote#i', $tag))
			{
				$message = preg_replace("#\[quote=(?:&quot;|\"|')?(.*?)[\"']?(?:&quot;|\"|')?\](.*)\[\/quote\](\r\n?|\n?)#si", "[quote=$1]".$mybb->settings['scd_hide_fg_text']."[/quote]\n", $message);
				$message = preg_replace('#\['.$tag.'\].*\[/'.$tag.'\]#si', '['.$tag.']'.$mybb->settings['scd_hide_fg_text'].'[/'.$tag.']', $message);
			}
			else
			{
				$message .= '\n\nThis message is displayed in error. Please inform the Admin that there is a bug in the SCD Hide Things Plugin!';
			}
		}
	}
	
	return $message;
}

function scd_hide_fg_parse_reply($page)
{
	global $db, $mybb, $fid;
	
	if((!isset($fid) || empty($fid)) && is_array($page))
	{
		$query = $db->simple_select("threads", "fid", "tid='{$page['tid']}'");
		$fid = $db->fetch_field($query, "fid");
		$db->free_result($query);
	}

	// Parse the message for code tags, and replace the contents with a little message.
	if(in_array($mybb->user['usergroup'], explode(',', $mybb->settings['scd_hide_fg_groups'])))
	{
		if(!empty($mybb->settings['scd_hide_fg_forums']) && !in_array($fid, explode(',', $mybb->settings['scd_hide_fg_forums'])))
		{
			return $page;
		}
		foreach(explode(',', $mybb->settings['scd_hide_fg_tohide']) as $tag)
		{
			if(!preg_match('#quote#i', $tag))
			{
				$page = preg_replace('#\['.$tag.'\].*?\[/'.$tag.'\]#si', '['.$tag.']'.$mybb->settings['scd_hide_fg_text'].'[/'.$tag.']', $page);
				$page = preg_replace('#\['.$tag.'=.*?\].*?\[/'.$tag.'\]#si', '['.$tag.'='.$mybb->settings['scd_hide_fg_text'].']'.$mybb->settings['scd_hide_fg_text'].'[/'.$tag.']', $page);
			}
			else if (preg_match('#quote#i', $tag))
			{
				$page = preg_replace("#\[quote=(?:&quot;|\"|')?(.*?)[\"']?(?:&quot;|\"|')?\](.*)\[\/quote\](\r\n?|\n?)#si", "[quote=$1]".$mybb->settings['scd_hide_fg_text']."[/quote]\n", $page);
				$page = preg_replace('#\['.$tag.'\].*\[/'.$tag.'\]#si', '['.$tag.']'.$mybb->settings['scd_hide_fg_text'].'[/'.$tag.']', $page);
			}
			else
			{
				$page .= '\n\nThis message is displayed in error. Please inform the Admin that there is a bug in the SCD Hide Things Plugin!';
			}
		}
	}
	
	return;
}

?>